@@ -8,7 +8,7 @@ use core::convert::TryFrom;
 use itertools::Itertools;
 use k8s_openapi::api::core::v1::{Node, Pod};
 use kube::api::{Api, ListParams, ObjectList};
-#[cfg(prettytable)]
+#[cfg(feature = "prettytable")]
 use prettytable::{cell, format, row, Cell, Row, Table};
 use qty::Qty;
 use std::collections::BTreeMap;
@@ -209,7 +209,7 @@ pub async fn extract_allocatable_from_nodes(
             node_name: node.metadata.name,
             ..Location::default()
         };
-        if let Some(als) = node.status.map(|v| v.allocatable) {
+        if let Some(als) = node.status.and_then(|v| v.allocatable) {
             // add_resource(resources, &location, ResourceUsage::Allocatable, &als)?
             for (kind, value) in als.iter() {
                 let quantity =
@@ -254,11 +254,10 @@ pub fn is_scheduled(pod: &Pod) -> bool {
                     "Succeeded" | "Failed" => Some(false),
                     "Running" => Some(true),
                     "Unknown" => None, // this is the case when a node is down (kubelet is not responding)
-                    "Pending" => Some(
-                        ps.conditions
-                            .iter()
-                            .any(|c| c.type_ == "PodScheduled" && c.status == "True"),
-                    ),
+                    "Pending" => ps.conditions.as_ref().map(|o| {
+                        o.iter()
+                            .any(|c| c.type_ == "PodScheduled" && c.status == "True")
+                    }),
                     &_ => None, // should not happen
                 }
             })
@@ -353,32 +352,30 @@ pub async fn extract_allocatable_from_pods(
         let containers = spec.map(|s| s.containers.clone()).unwrap_or_default();
         for container in containers.into_iter() {
             if let Some(requirements) = container.resources {
-                process_resources(
-                    &mut resource_requests,
-                    &requirements.requests,
-                    std::ops::Add::add,
-                )?;
-                process_resources(
-                    &mut resource_limits,
-                    &requirements.limits,
-                    std::ops::Add::add,
-                )?;
+                if let Some(r) = requirements.requests {
+                    process_resources(&mut resource_requests, &r, std::ops::Add::add)?
+                }
+                if let Some(r) = requirements.limits {
+                    process_resources(&mut resource_limits, &r, std::ops::Add::add)?;
+                }
             }
         }
         // handle initContainers
-        let init_containers = spec.map(|s| s.init_containers.clone()).unwrap_or_default();
+        let init_containers = spec
+            .and_then(|s| s.init_containers.clone())
+            .unwrap_or_default();
         for container in init_containers.into_iter() {
             if let Some(requirements) = container.resources {
-                process_resources(
-                    &mut resource_requests,
-                    &requirements.requests,
-                    std::cmp::max,
-                )?;
-                process_resources(&mut resource_limits, &requirements.limits, std::cmp::max)?;
+                if let Some(r) = requirements.requests {
+                    process_resources(&mut resource_requests, &r, std::cmp::max)?;
+                }
+                if let Some(r) = requirements.limits {
+                    process_resources(&mut resource_limits, &r, std::cmp::max)?;
+                }
             }
         }
         // handler overhead (add to both requests and limits)
-        if let Some(overhead) = spec.map(|s| &s.overhead) {
+        if let Some(ref overhead) = spec.and_then(|s| s.overhead.clone()) {
             process_resources(&mut resource_requests, &overhead, std::ops::Add::add)?;
             process_resources(&mut resource_limits, &overhead, std::ops::Add::add)?;
         }
@@ -726,7 +723,7 @@ fn add_cells_for_cvs(row: &mut Vec<String>, oqty: &Option<Qty>, o100: &Option<Qt
     };
 }
 
-#[cfg(not(prettytable))]
+#[cfg(not(feature = "prettytable"))]
 pub fn display_with_prettytable(
     _data: &[(Vec<String>, Option<QtyByQualifier>)],
     _filter_full_zero: bool,
@@ -735,7 +732,7 @@ pub fn display_with_prettytable(
     warn!("feature 'prettytable' not enabled");
 }
 
-#[cfg(prettytable)]
+#[cfg(feature = "prettytable")]
 pub fn display_with_prettytable(
     data: &[(Vec<String>, Option<QtyByQualifier>)],
     filter_full_zero: bool,
@@ -811,7 +808,7 @@ pub fn display_with_prettytable(
     table.printstd();
 }
 
-#[cfg(prettytable)]
+#[cfg(feature = "prettytable")]
 fn is_empty(oqty: &Option<Qty>) -> bool {
     match oqty {
         Some(qty) => qty.is_zero(),
@@ -819,7 +816,7 @@ fn is_empty(oqty: &Option<Qty>) -> bool {
     }
 }
 
-#[cfg(prettytable)]
+#[cfg(feature = "prettytable")]
 fn make_cell_for_prettytable(oqty: &Option<Qty>, o100: &Option<Qty>) -> Cell {
     let txt = match oqty {
         None => "__".to_string(),
